@@ -19,47 +19,36 @@ def blacken_pixels(ds: Dataset) -> Dataset:
     """
     try:
         ## Modality CT and Agfa
-        if (ds.Modality == 'CT') \
-                and (ds.Manufacturer == 'Agfa') \
-                and (ds.Rows == 775) \
-                and (ds.Columns == 1024):
+        if ds.Manufacturer == 'Agfa' and ds.Rows == 775 and ds.Columns == 1024:
             img = ds.pixel_array
-            img[0:round(img.shape[0] * 0.07), :] = 0  # ca. 7%
+            img[0:round(img.shape[0] * 0.07), :, :] = 0  # ca. 7%
 
-            ds.PixelData = img.tobytes()
-            ds.PhotometricInterpretation = 'YBR_FULL'                   # important!!
-            ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian     # because changed
+            ds.PixelData = img
+            ds.PhotometricInterpretation = 'YBR_FULL'  # important!!
+            ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian  # because changed
 
         ## Modality US and PHILIPS
-        if ds.ManufacturerModelName in ('EPIQ 7C', 'iE33') \
-                and ds.Rows == 600 \
-                and ds.Columns == 800:
+        if ds.ManufacturerModelName in ('EPIQ 7C', 'iE33') and ds.Rows == 600 and ds.Columns == 800:
             img = ds.pixel_array
             img = np.repeat(img[:, :, :, 0, np.newaxis], 3, axis=3)
             img[:, 0:round(img.shape[1] * 0.1), :, :] = 0
 
             ds.PixelData = img
-            ds.PhotometricInterpretation = 'RGB'                        # important!!
-            ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian     # because changed
+            ds.PhotometricInterpretation = 'RGB'  # important!!
+            ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian  # because changed
 
-        if ds.ManufacturerModelName in ('EPIQ 7C', 'iE33') \
-                and ds.Rows == 768 \
-                and ds.Columns == 1024:
+        if ds.ManufacturerModelName in ('EPIQ 7C', 'iE33') and ds.Rows == 768 and ds.Columns == 1024:
             img = ds.pixel_array
 
             if ds.PhotometricInterpretation == 'MONOCHROME2':
-                img[0:round(img.shape[0] * 0.1), :] = 0
                 ds.PhotometricInterpretation = 'YBR_FULL'
 
-            else:
-                img[0:round(img.shape[0] * 0.1), :, :] = 0
-
+            img[0:round(img.shape[0] * 0.1), :] = 0
             ds.PixelData = img
             ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian  # because changed
 
         ## Modality US and GE
-        if ds.ManufacturerModelName == 'Vivid E95' \
-                and ds.Rows == 708:
+        if ds.ManufacturerModelName == 'Vivid E95' and ds.Rows == 708:
             img = ds.pixel_array
             try:
                 img = np.repeat(img[:, :, :, 0, np.newaxis], 3, axis=3)
@@ -73,35 +62,44 @@ def blacken_pixels(ds: Dataset) -> Dataset:
                 ds.PhotometricInterpretation = 'RGB'
                 ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian  # because changed
 
-        if ds.ManufacturerModelName == 'Vivid E95' \
-                and ds.Rows == 758:
+        if ds.ManufacturerModelName == 'Vivid E95' and ds.Rows == 758:
             img = ds.pixel_array
             try:
-
                 img = np.repeat(img[:, :, :, 0, np.newaxis], 3, axis=3)
                 img[:, 0:round(img.shape[1] * 0.065), :, :] = 0
             except:
                 img = np.repeat(img[:, :, 0, np.newaxis], 3, axis=2)
-                img[0:round(img.shape[1] * 0.05), :, :] = 0
+                img[0:round(img.shape[0] * 0.065), :, :] = 0
             finally:
                 ds.PixelData = img
-                ds.PhotometricInterpretation = 'RGB'
+                ds.PhotometricInterpretation = 'RGB'  # important!!
                 ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian  # because changed
 
         if ds.ManufacturerModelName == 'Vivid E9':
             img = ds.pixel_array
             try:
-
                 img = np.repeat(img[:, :, :, 0, np.newaxis], 3, axis=3)
                 img[:, 0:round(img.shape[1] * 0.1), :, :] = 0
             except:
                 img = np.repeat(img[:, :, 0, np.newaxis], 3, axis=2)
-                img[0:round(img.shape[1] * 0.072), :, :] = 0
+                img[0:round(img.shape[0] * 0.1), :, :] = 0
             finally:
                 ds.PixelData = img
                 ds.PhotometricInterpretation = 'RGB'  # important!!
                 ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian  # because changed
 
+        if ds.ManufacturerModelName == 'TUS-AI900' and 'CARDIOLOGY' in ds.ImageType:
+            img = ds.pixel_array
+            try:
+                img = np.repeat(img[:, :, :, 0, np.newaxis], 3, axis=3)
+                img[:, 0:round(img.shape[1] * 0.072), :, :] = 0
+                ds.PhotometricInterpretation = 'RGB'  # important!!
+            except:
+                img[0:round(img.shape[0] * 0.072), :, :] = 0
+            finally:
+                ds.PixelData = img
+                ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian  # because changed
+
         return ds
 
     except AttributeError:
@@ -125,11 +123,14 @@ def delete_dicom(ds: Dataset) -> Optional[Dataset]:
             return None
 
         if ds.ManufacturerModelName == 'Vivid E95' \
-                and ds.Rows == 708\
-                and ds.NumberOfFrames is None\
+                and ds.Rows == 708 \
+                and ds.NumberOfFrames is None \
                 and ds.BurnedInAnnotation is None:
             return None
 
+        if ds.ManufacturerModelName == 'TUS-AI900' \
+                and 'CARDIOLOGY' not in ds.ImageType:
+            return None
 
         return ds
 
